/*
FILE: PS2PadThrottle.h
DESCRIPTION: Implementation file for the PS2PadInputThrottle and PS2PadThrottle classes
WRITTEN BY: Derek Nedelman (nedelman@netzero.net)
DATE: August 12, 2002
HOME PAGE: http://www.playstation2-linux.com/projects/joypadlib 
*/


#ifndef PS2PAD_THROTTLE_INCLUDED
#define PS2PAD_THROTTLE_INCLUDED

//Includes--------------------------------------------------------------------- 
#include "PS2Pad.h"


//Classes----------------------------------------------------------------------
class PS2PadInputThrottle
{
protected:
	enum ThrottleState {NOT_PRESSED, PRESSED, HOLDING};

	bool pressed;		//Whether or not the input being throttled is to be considered active
	ThrottleState state;//The current state of the throttling mechanism
	float holdCount,	//The number of seconds the input has been held
		  threshold;	//The maximum number of seconds the input can be held before it is again
						//considered "pressed"

public:
	PS2PadInputThrottle(float threshold = 0.0f)
	{
		pressed = false;
		state = NOT_PRESSED;
		holdCount = 0.0f;		
		this->threshold = threshold;
	}
	bool IsPressed() const	{return pressed;}
	void SetThreshold(float t)	{threshold = t;}
	void Update(float elapsedTime, bool actuallyPressed);
	void Reset()
	{
		pressed = false;
		state = NOT_PRESSED;
		holdCount = 0.0f;
	}
};


class PS2PadThrottle
{
	PS2Pad* pad;
	float leftStick[2];
	float rightStick[2];

	PS2PadInputThrottle stick0ThrottleLeft, stick0ThrottleRight, 
						stick0ThrottleUp, stick0ThrottleDown;
	PS2PadInputThrottle stick1ThrottleLeft, stick1ThrottleRight, 
						stick1ThrottleUp, stick1ThrottleDown;
	PS2PadInputThrottle buttonThrottles[PS2Pad::NUM_BUTTONS];

public:
	PS2PadThrottle()			{pad = 0;}

	void SetPad(PS2Pad* pad)	{this->pad = pad; Reset();}
	PS2Pad* GetPad()			{return pad;}
		
	void Update(float elapsedTime);
	void Reset();

	void SetButtonThresholds(unsigned long buttons, float threshold);
	void SetStickThresholds(int stick, float left, float right, float up, float down);

	bool IsButtonPressed(int button) const {return buttonThrottles[button].IsPressed();}	
	void GetSticks(float leftStick[2], float rightStick[2]) const;
	float GetLeftX() const;
	float GetLeftY() const;
	float GetRightX() const;
	float GetRightY() const;
};


#endif
