/*
FILE: main_basic.cpp
DESCRIPTION: Test file demonstrating basic usage of the PS2Pad library
WRITTEN BY: Derek Nedelman (nedelman@netzero.net)
DATE: August 12, 2002
NOTES:
	-About checking button velocities: a velocity != 0 only lasts for a short time
         so it may be hard to actually see the velocities printed out.
HOME PAGE: http://www.playstation2-linux.com/projects/joypadlib 
*/

#include <stdio.h>
#include "PS2Pad.h"

void PrintStats()
{
	int i;
	int numJoypads;
	PS2Pad* joypad;

	numJoypads = PS2PadManager::GetNumPads();

	printf("Total joypads: %d\n", numJoypads);
	
	for (i = 0; i < numJoypads; i++)
	{
		joypad = PS2PadManager::GetPad(i);
		switch (joypad->IsPluggedIn())
		{
			case true: printf("Joypad %d: Connected\n", i); break;
			case false: printf("Joypad %d: Not plugged in\n", i); break;
		}
	}
	printf("\n");

	for (i = 0; i < numJoypads; i++)
	{
		joypad = PS2PadManager::GetPad(i);
		switch (joypad->GetType())
		{
			case PS2PAD_TYPE_NEJICON: printf("Joypad %d: Nejicon\n", i); break;
			case PS2PAD_TYPE_DIGITAL: printf("Joypad %d: Digital\n", i); break;      
			case PS2PAD_TYPE_ANALOG: printf("Joypad %d: Analog\n", i); break;
			case PS2PAD_TYPE_DUALSHOCK: printf("Joypad %d: Dual shock\n", i); break; 		
		}
	}
	printf("\n");
}

int main(int argc, char** argv)
{
	PS2Pad* joypad;
	
	PS2PadManager::Initialize();
	joypad = PS2PadManager::GetPad(0);

	PrintStats();
	
	puts("Press anything on the joypad to see something happen.");
	puts("Press the START button to exit.");
	
	for (;;) 
	{
		PS2PadManager::Update();
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_LEFT))
		{
			printf("Pressed left. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_LEFT), joypad->GetVelocity(PS2Pad::BUTTON_LEFT));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_UP))
		{
			printf("Pressed up. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_UP), joypad->GetVelocity(PS2Pad::BUTTON_UP));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_RIGHT))
		{
			printf("Pressed right. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_RIGHT), joypad->GetVelocity(PS2Pad::BUTTON_RIGHT));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_DOWN))
		{
			printf("Pressed down. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_DOWN), joypad->GetVelocity(PS2Pad::BUTTON_DOWN));
		}
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_L1))
		{
			printf("Pressed L1. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_L1), joypad->GetVelocity(PS2Pad::BUTTON_L1));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_L2))
		{
			printf("Pressed L2. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_L2), joypad->GetVelocity(PS2Pad::BUTTON_L2));
		}
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_L3))
		{
			puts("Pressed L3");
		}
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_R1))
		{
			printf("Pressed R1. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_R1), joypad->GetVelocity(PS2Pad::BUTTON_R1));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_R2))
		{
			printf("Pressed R2. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_R2), joypad->GetVelocity(PS2Pad::BUTTON_R2));
		}
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_R3))
		{
			puts("Pressed R3");
		}
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_START))
		{
			puts("Pressed start");
			break;
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_SELECT))
		{
			puts("Pressed select");
		}
		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_TRIANGLE))
		{
			printf("Pressed triangle. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_TRIANGLE), joypad->GetVelocity(PS2Pad::BUTTON_TRIANGLE));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_CIRCLE))
		{			
			printf("Pressed circle. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_CIRCLE), joypad->GetVelocity(PS2Pad::BUTTON_CIRCLE));
		}		
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_SQUARE))
		{
			printf("Pressed square. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_SQUARE), joypad->GetVelocity(PS2Pad::BUTTON_SQUARE));
		} 
		if (joypad->IsButtonPressed(PS2Pad::BUTTON_CROSS))
		{
			printf("Pressed cross. Pressure: %f. Velocity: %f\n", joypad->GetPressure(PS2Pad::BUTTON_CROSS), joypad->GetVelocity(PS2Pad::BUTTON_CROSS));
		}	

		if ((joypad->GetLeftX() != 0.0f) || (joypad->GetLeftY() != 0.0f))
		{
			printf("Left stick x/y: %f %f\n", joypad->GetLeftX(), joypad->GetLeftY());
		}

		if ((joypad->GetRightX() != 0.0f) || (joypad->GetRightY() != 0.0f))
		{
			printf("Right stick x/y: %f %f\n", joypad->GetRightX(), joypad->GetRightY());
		}		
	}
	
	PS2PadManager::Shutdown();
	return 0;
}
